/*
 * Student.java
 *
 * version: 30th November, 14:03
 * authors: yanas
 */
package cz.yanas.pb162.students;

import java.text.DateFormat;
import java.util.Date;

/**
 * Represents a student.
 *
 * @author yanas
 */
public final class Student implements Comparable<Student> {

    /** student's identification number */
    private final int id;
    /** student's surname */
    private final String surname;
    /** student's name */
    private final String name;
    /** student's date of birth */
    private final Date dateOfBirth;

    /**
     * Constructs an instance of the Student class using the given parameters.
     *
     * @param id the student's identification number
     * @param surname student's surname
     * @param name student's name
     * @param dateOfBirth student's date of birth
     *
     * @throws IllegalArgumentException if the id is invalid
     * @throws NullPointerException if any argument is null
     */
    public Student(int id, String surname, String name, Date dateOfBirth) {
        // throw an IllegalArgumentException if the id is less than one
        if (id <= 0) {
            throw new IllegalArgumentException("id <= 0");
        }

        // throw a NullPointerException if the surname is null
        if (surname == null) {
            throw new NullPointerException("surname");
        }

        // throw a NullPointerException if the name is null
        if (name == null) {
            throw new NullPointerException("name");
        }

        // throw a NullPointerException if the dateOfBirth is null
        if (dateOfBirth == null) {
            throw new NullPointerException("dateOfBirth");
        }

        // initialize all the attributes
        this.id = id;
        this.surname = surname;
        this.name = name;
        this.dateOfBirth = dateOfBirth;
    }

    /**
     * Returns the student's identification number.
     *
     * @return the student's identification number
     */
    public int getId() {
        return id;
    }

    /**
     * Returns the student's surname.
     *
     * @return the student's surname
     */
    public String getSurname() {
        return surname;
    }

    /**
     * Returns the student's name.
     *
     * @return the student's name
     */
    public String getName() {
        return name;
    }

    /**
     * Returns the student's date of birth.
     *
     * @return the student's date of birth
     */
    public Date getDateOfBirth() {
        return dateOfBirth;
    }

    /**
     * Returns true if the given object is equal to this instance, false otherwise.
     *
     * @param object an object to be compared with this instance
     *
     * @return true if the given object is equal to this instance
     */
    @Override
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        }

        if (!(object instanceof Student)) {
            return false;
        }

        return (((Student) object).getId() == id);
    }

    /**
     * Returns the hash code of this instance.
     *
     * @return the hash code of this instance
     */
    @Override
    public int hashCode() {
        return id;
    }

    /**
     * Returns the string representation of this instance.
     *
     * @return the string representation of this instance
     */
    @Override
    public String toString() {
        return ("#" + id + ", " + surname + " " + name + ", "
                + DateFormat.getDateInstance().format(dateOfBirth));
    }

    /**
     * Compares the given student to this instance and returns corresponding int value.
     *
     * @param student a student to be compared to this instance
     *
     * @return an integer representing the relation between the students
     *
     * @throws NullPointerException if the given student is null
     */
    public int compareTo(Student student) {
        // return a NullPointerException if the student is null
        if (student == null) {
            throw new NullPointerException("student");
        }

        // simply substract the second student id from the first one
        return (id - student.getId());
    }
}
