/*
 * StudentDateOfBirthComparator.java
 *
 * version: 30th November, 10:22
 * authors: yanas
 */
package cz.yanas.pb162.students;

import java.util.Comparator;

/**
 * Represents a comparator for comparing students by their date of birth.
 *
 * @author yanas
 */
public final class StudentDateOfBirthComparator implements Comparator<Student> {

    /** the only instance of the StudentDateOfBirthComparator class */
    private static final StudentDateOfBirthComparator INSTANCE =
            new StudentDateOfBirthComparator();

    /**
     * This class uses the Singleton design pattern!
     */
    private StudentDateOfBirthComparator() {
    }

    /**
     * Compares the given students by date of birth and returns corresponding int value.
     *
     * @param studentOne the first student to be compared
     * @param studentTwo the second student to be compared
     *
     * @return an integer representing the relation between the students
     *
     * @throws NullPointerException if any student is null
     */
    public int compare(Student studentOne, Student studentTwo) {
        // throw a NullPointerException if the studentOne is null
        if (studentOne == null) {
            throw new NullPointerException("studentOne");
        }

        // throw a NullPointerException if the studentTwo is null
        if (studentTwo == null) {
            throw new NullPointerException("studentTwo");
        }

        // simply compare the dates of bith of both students
        return studentOne.getDateOfBirth().compareTo(studentTwo.getDateOfBirth());
    }

    /**
     * Returns the only instance of the StudentDateOfBirthComparator class.
     *
     * @return the only instance of the StudentDateOfBirthComparator class
     */
    public static StudentDateOfBirthComparator getInstance() {
        return INSTANCE;
    }
}
