/*
 * StudentFullNameComparator.java
 *
 * version: 30th November, 10:22
 * authors: yanas
 */
package cz.yanas.pb162.students;

import java.util.Comparator;

/**
 * Represents a comparator for comparing students by their full name.
 *
 * @author yanas
 */
public final class StudentFullNameComparator implements Comparator<Student> {

    /** the only instance of the StudentFullNameComparator class */
    private static final StudentFullNameComparator INSTANCE =
            new StudentFullNameComparator();

    /**
     * This class uses the Singleton design pattern!
     */
    private StudentFullNameComparator() {
    }

    /**
     * Compares the given students by full name and returns corresponding int value.
     *
     * @param studentOne the first student to be compared
     * @param studentTwo the second student to be compared
     *
     * @return an integer representing the relation between the students
     *
     * @throws NullPointerException if any student is null
     */
    public int compare(Student studentOne, Student studentTwo) {
        // throw a NullPointerException if the studentOne is null
        if (studentOne == null) {
            throw new NullPointerException("studentOne");
        }

        // throw a NullPointerException if the studentTwo is null
        if (studentTwo == null) {
            throw new NullPointerException("studentTwo");
        }

        // compare the students by surname first and save the result
        int comparisonResult = studentOne.getSurname().compareTo(studentTwo.getSurname());

        // return the comparison result if their surnames are not equal
        if (comparisonResult != 0) {
            return comparisonResult;
        }

        // else compare students by their names
        return studentOne.getName().compareTo(studentTwo.getName());
    }

    /**
     * Returns the only instance of the StudentFullNameComparator class.
     *
     * @return the only instance of the StudentFullNameComparator class
     */
    public static StudentFullNameComparator getInstance() {
        return INSTANCE;
    }
}
