/*
 * Students.java
 *
 * version: 30th November, 14:22
 * authors: yanas
 */
package cz.yanas.pb162.students;

import java.util.Calendar;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import java.util.SortedSet;
import java.util.TreeSet;

/**
 * Demonstrates the functionality of the Student and StudentRegister classes.
 *
 * @author yanas
 */
public final class Students {

    /**
     * This class cannot be instantiated!
     */
    private Students() {
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        // get an instance of the Calendar class and clear all fields
        Calendar calendar = Calendar.getInstance();
        calendar.clear();

        // create a set of students
        Set<Student> students = new HashSet<Student>();

        // insert eight students to the set
        calendar.set(1982, 1, 1);
        students.add(new Student(8, "Adamec", "Adam", calendar.getTime()));
        calendar.set(1984, 2, 2);
        students.add(new Student(1, "Borec", "Boleslav", calendar.getTime()));
        calendar.set(1986, 3, 3);
        students.add(new Student(6, "Cervena", "Cecilie", calendar.getTime()));
        calendar.set(1988, 4, 4);
        students.add(new Student(3, "Duhova", "Dalimila", calendar.getTime()));
        calendar.set(1981, 5, 5);
        students.add(new Student(4, "Euler", "Emil", calendar.getTime()));
        calendar.set(1983, 6, 6);
        students.add(new Student(5, "Fialova", "Felicie", calendar.getTime()));
        calendar.set(1985, 7, 7);
        students.add(new Student(2, "Graham", "Gruber", calendar.getTime()));
        calendar.set(1987, 8, 8);
        students.add(new Student(7, "Hrach", "Hugo", calendar.getTime()));

        // print out the youngest student
        System.out.println("The youngest student:");
        System.out.println(Collections.max(students,
                StudentDateOfBirthComparator.getInstance()));
        System.out.println();

        // print out the oldest student
        System.out.println("The oldest student:");
        System.out.println(Collections.min(students,
                StudentDateOfBirthComparator.getInstance()));
        System.out.println();

        // print out the first student in alphabetical order
        System.out.println("First student in alphabetical order:");
        System.out.println(Collections.min(students,
                StudentFullNameComparator.getInstance()));
        System.out.println();

        // print out the last student in alphabetical order
        System.out.println("Last student in alphabetical order:");
        System.out.println(Collections.max(students,
                StudentFullNameComparator.getInstance()));
        System.out.println();

        // create a set of students sorted by their id
        SortedSet<Student> sortedStudents = new TreeSet<Student>(students);

        // for each student in the sorted set (in the right order)
        for (Student student : sortedStudents) {
            // print out the student
            System.out.println(student);
        }

        // separate the student by an empty line
        System.out.println();

        // create a new student register
        StudentRegister register = new StudentRegister();

        // create some students
        calendar.set(1985, 10, 4);
        register.createStudent("Zakopalova", "Zita", calendar.getTime());
        calendar.set(1987, 3, 23);
        register.createStudent("Prachac", "Pepa", calendar.getTime());
        calendar.set(1983, 9, 9);
        register.createStudent("Slanina", "Stepan", calendar.getTime());
        calendar.set(1985, 5, 17);
        register.createStudent("Mrazkova", "Michaela", calendar.getTime());

        // print out first two students
        System.out.println("Students with id = 1 and id = 2:");
        System.out.println(register.getStudentById(1));
        System.out.println(register.getStudentById(2));
        System.out.println();

        // print out students sorted by full name and then sorted by the date of birth
        System.out.println(register.getStudentsSortedByFullName());
        System.out.println(register.getStudentsSortedByDateOfBirth());
        System.out.println();

        // cause an exception to be thrown
        System.out.println(register.getStudentById(-1));
    }
}
